==> ja-WiKicker-0.23.tbz: lib/perl5/site_perl/5.8.5/WiKicker/HTML/LinkMaker.pm <==
#
# WiKicker
#
#  LinkMaker.pm
#
#
# Copyright (C) 2003,2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: LinkMaker.pm,v 1.12 2004/05/30 04:08:32 naney Exp $
#
#

package WiKicker::HTML::LinkMaker;

use 5.005;
use strict;
use WiKicker::URI;
use WiKicker::HTML;
use WiKicker::PageName;
use WiKicker::Time;
use Carp;

use vars qw(%required_param);
BEGIN {
  %required_param = (script_url => 1,
                     db => 1,
                     configuration => 1,
                     timezone => 1,
                     localizer => 1,
                     page_name_list => 1);
}

sub new {
  my ($class, %param) = @_;

  my $self = bless {}, $class;

  for my $key (keys %required_param) {
    croak "$class: no $key param" unless exists $param{$key};
    $self->{$key} = $param{$key};
  }
  croak "empty script_url" if $self->script_url eq '';

  return $self;
}

sub new_from_html_env {
  my ($class, %param) = @_;

  unless (exists $param{env}) {
    croak "no env";
  }
  my $env = $param{env};
  delete $param{env};

  unless (exists $param{page_name_list}) {
    $param{page_name_list} = $env->page_name_list;
  }
  unless (exists $param{script_url}) {
    $param{script_url} = $env->wikicker_url;
  }
  unless (exists $param{db}) {
    $param{db} = $env->db;
  }
  unless (exists $param{timezone}) {
    $param{timezone} = $env->user ? ($env->user->timezone || 'GMT') : 'GMT';
  }
  unless (exists $param{configuration}) {
    $param{configuration} = $env->configuration;
  }
  unless (exists $param{localizer}) {
    $param{localizer} = $env->localizer;
  }

  return new($class, %param);
}

sub page_name_list { shift->{page_name_list} }
sub script_url     { shift->{script_url} }
sub timezone       { shift->{timezone} }
sub db             { shift->{db} }
sub configuration  { shift->{configuration} }
sub localizer      { shift->{localizer} }

sub make_page_read_href {
  my ($self, $page_name) = @_;

  if (exists $self->{page_read_href}->{$page_name}) {
    return $self->{page_read_href}->{$page_name};
  }
  else {
    return $self->{page_read_href}->{$page_name}
      = $self->make_page_read_uri($page_name);
  }
}

sub make_page_read_uri {
  my ($self, $page_name) = @_;

  WiKicker::URI::make_read_page_url($self->script_url, $page_name);
}

sub edit_uri {
  my ($self, $page_name) = @_;

  if (exists $self->{edit_uri_cache}->{$page_name}) {
    return $self->{edit_uri_cache}->{$page_name};
  }
  else {
    return $self->{edit_uri_cache}->{$page_name} = $self->script_url .
      '?edit=' . WiKicker::URI::escape_URI($page_name);
  }
}

sub make_dangling_link {
  my ($self, $page_name, $content) = @_;

  my $href = $self->edit_uri($page_name);
  my $content_string = WiKicker::HTML::escape($content || $page_name);
  my $title = '';
  if ($self->localizer) {
    $title = WiKicker::HTML::escape_attribute($self->localizer->maketext("Be the first person to write '[_1]' page in this Forum", $page_name));
  }
  return qq(<a href="$href" title="$title">?</a><span class="DanglingLink">$content_string</span>);
}

sub make_fragment_identifier_link {
  my ($self, $fragment_identifier, $content) = @_;

  my $href = '#' . WiKicker::URI::escape_URI($fragment_identifier);
  my $content_string = WiKicker::HTML::escape($content || $fragment_identifier);
  return qq(<a href="$href">$content_string</a>);
}

sub _make_time_str {
  my ($self, $time) = @_;

  my $time_str;
  $time_str = $self->localizer->language_handle->date_str($time, $self->timezone);
  return qq(<span class="date">$time_str</span>);
}

sub make_exists_page_link {
  my ($self, $page_name, $content, $mtime_flag, $subject_flag) = @_;

  my $base = $self->_make_exists_page_link_base($page_name, $content);
  unless ($mtime_flag || $subject_flag) {
    return $base;
  }
  else {
    my $time_str = '';
    if ($mtime_flag) {
      my $time = $self->db->last_modified($page_name);
      $time_str = $self->_make_time_str($time);
    }
    my $subject = '';
    if ($subject_flag) {
      $subject = $self->db->page_subject($page_name);
      if ($subject) {
        $subject = ' - ' . WiKicker::HTML::escape($subject);
      }
    }
    if ($time_str || $subject) {
      return qq($base <small>$time_str$subject</small>);
    }
    else {
      return $base;
    }
  }
}

sub make_pseudo_page_link {
  my ($self, $page_name, $content) = @_;

  my $href = $self->make_page_read_href($page_name);
  $content = WiKicker::HTML::escape($content || $page_name);

  return qq(<a href="$href">$content</a>);
}


sub _make_exists_page_link_base {
  my ($self, $page_name, $content) = @_;


  if ((! $content) && exists $self->{_page_link_base_cache}->{$page_name}) {
    return $self->{_page_link_base_cache}->{$page_name};
  }

  my $href = $self->make_page_read_href($page_name);
  $content = WiKicker::HTML::escape($content || $page_name);
  #my $subject = WiKicker::HTML::escape_attribute($self->db->page_subject($page_name));
  #my $link = qq(<a href="$href" title="$subject">$content</a>);
  my $link = qq(<a href="$href">$content</a>);
  if (!$content) {
    $self->{_page_link_base_cache}->{$page_name} = $link;
  }
  return $link;
}

sub make_page_name_link {
  my ($self, $page_name, $fragment_identifier, $content, $mtime_flag, $subject_flag) = @_;
  my ($link, $linked) =
    $self->make_page_name_link_and_linked($page_name, $fragment_identifier,
                                          $content, $mtime_flag, $subject_flag);
  return $link;
}

sub make_page_name_link_and_linked {
  my ($self, $page_name, $fragment_identifier, $content, $mtime_flag, $subject_flag) = @_;
  $page_name = WiKicker::PageName::normalize($page_name);

  # fragment identifier only?
  if ((! $page_name) && $fragment_identifier) {
    my $link = $self->make_fragment_identifier_link($fragment_identifier, $content);
    return ($link, []);
  }

  # exists page?
  #if ($self->db->exists_live_page($page_name)) {
  if ($self->page_name_list->has($page_name)) {
    my $link =  $self->make_exists_page_link($page_name, $content, $mtime_flag, $subject_flag);
    return ($link, [$page_name]);
  }

  # pseudo page?
  if ($self->configuration->is_pseudo_page($page_name)) {
    my $link = $self->make_pseudo_page_link($page_name, $content);
    return ($link, [$page_name]);
  }

  my @full_page_name_list = $self->page_name_list->full_page_name_list($page_name);

  # exists one match page.
  if (@full_page_name_list == 1) {
    my $link =  $self->
      make_exists_page_link($full_page_name_list[0],
                            $content || $page_name,
                            $mtime_flag, $subject_flag);
    return($link, [ $full_page_name_list[0] ]);
  }

  # exists some match pages.
  if (@full_page_name_list > 1) {
    my $content = WiKicker::HTML::escape($content || $page_name);
    my $result = $content;
    my $i = 0;
    for my $full_name (@full_page_name_list) {
      $i++;
      my $href = $self->make_page_read_href($full_name);
      my $title = WiKicker::HTML::escape($full_name);
      $result .= qq([<a href="$href" title="$title">$i</a>]);
    }
    $result .= ' ';
    return ($result, \@full_page_name_list);
  }

  # dangling link
  my $link = $self->make_dangling_link($page_name, $content);
  return ($link, [ $page_name ]);
}


1;

==> ja-WiKicker-0.26.tbz: lib/perl5/site_perl/5.8.9/WiKicker/HTML/LinkMaker.pm <==
#
# WiKicker
#
#  LinkMaker.pm
#
#
# Copyright (C) 2003,2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: LinkMaker.pm,v 1.13 2004/08/03 12:55:52 naney Exp $
#
#

package WiKicker::HTML::LinkMaker;

use 5.005;
use strict;
use WiKicker::URI;
use WiKicker::HTML;
use WiKicker::PageName;
use WiKicker::Time;
use Carp;

use vars qw(%required_param);
BEGIN {
  %required_param = (script_url => 1,
                     db => 1,
                     configuration => 1,
                     timezone => 1,
                     localizer => 1,
                     page_name_list => 1);
}

sub new {
  my ($class, %param) = @_;

  my $self = bless {}, $class;

  for my $key (keys %required_param) {
    croak "$class: no $key param" unless exists $param{$key};
    $self->{$key} = $param{$key};
  }
  croak 'empty script_url' if $self->script_url eq '';

  return $self;
}

sub new_from_html_env {
  my ($class, %param) = @_;

  unless (exists $param{env}) {
    croak 'no env';
  }
  my $env = $param{env};
  delete $param{env};

  unless (exists $param{page_name_list}) {
    $param{page_name_list} = $env->page_name_list;
  }
  unless (exists $param{script_url}) {
    $param{script_url} = $env->wikicker_url;
  }
  unless (exists $param{db}) {
    $param{db} = $env->db;
  }
  unless (exists $param{timezone}) {
    $param{timezone} = $env->user ? ($env->user->timezone || 'GMT') : 'GMT';
  }
  unless (exists $param{configuration}) {
    $param{configuration} = $env->configuration;
  }
  unless (exists $param{localizer}) {
    $param{localizer} = $env->localizer;
  }

  return new($class, %param);
}

sub page_name_list { shift->{page_name_list} }
sub script_url     { shift->{script_url} }
sub timezone       { shift->{timezone} }
sub db             { shift->{db} }
sub configuration  { shift->{configuration} }
sub localizer      { shift->{localizer} }

sub make_page_read_href {
  my ($self, $page_name) = @_;

  if (exists $self->{page_read_href}->{$page_name}) {
    return $self->{page_read_href}->{$page_name};
  }
  else {
    return $self->{page_read_href}->{$page_name}
      = $self->make_page_read_uri($page_name);
  }
}

sub make_page_read_uri {
  my ($self, $page_name) = @_;

  WiKicker::URI::make_read_page_url($self->script_url, $page_name);
}

sub edit_uri {
  my ($self, $page_name) = @_;

  if (exists $self->{edit_uri_cache}->{$page_name}) {
    return $self->{edit_uri_cache}->{$page_name};
  }
  else {
    return $self->{edit_uri_cache}->{$page_name} = $self->script_url .
      '?edit=' . WiKicker::URI::escape_URI($page_name);
  }
}

sub make_dangling_link {
  my ($self, $page_name, $content) = @_;

  my $href = $self->edit_uri($page_name);
  my $content_string = WiKicker::HTML::escape($content || $page_name);
  my $title = '';
  if ($self->localizer) {
    $title = WiKicker::HTML::escape_attribute($self->localizer->maketext(q(Be the first person to write '[_1]' page in this Forum), $page_name));
  }
  return qq(<a href="$href" title="$title">?</a><span class="DanglingLink">$content_string</span>);
}

sub make_fragment_identifier_link {
  my ($self, $fragment_identifier, $content) = @_;

  my $href = '#' . WiKicker::URI::escape_URI($fragment_identifier);
  my $content_string = WiKicker::HTML::escape($content || $fragment_identifier);
  return qq(<a href="$href">$content_string</a>);
}

sub _make_time_str {
  my ($self, $time) = @_;

  my $time_str;
  $time_str = $self->localizer->language_handle->date_str($time, $self->timezone);
  return qq(<span class="date">$time_str</span>);
}

sub make_exists_page_link {
  my ($self, $page_name, $content, $mtime_flag, $subject_flag) = @_;

  my $base = $self->_make_exists_page_link_base($page_name, $content);
  unless ($mtime_flag || $subject_flag) {
    return $base;
  }
  else {
    my $time_str = '';
    if ($mtime_flag) {
      my $time = $self->db->last_modified($page_name);
      $time_str = $self->_make_time_str($time);
    }
    my $subject = '';
    if ($subject_flag) {
      $subject = $self->db->page_subject($page_name);
      if ($subject) {
        $subject = ' - ' . WiKicker::HTML::escape($subject);
      }
    }
    if ($time_str || $subject) {
      return qq($base <small>$time_str$subject</small>);
    }
    else {
      return $base;
    }
  }
}

sub make_pseudo_page_link {
  my ($self, $page_name, $content) = @_;

  my $href = $self->make_page_read_href($page_name);
  $content = WiKicker::HTML::escape($content || $page_name);

  return qq(<a href="$href">$content</a>);
}


sub _make_exists_page_link_base {
  my ($self, $page_name, $content) = @_;


  if ((! $content) && exists $self->{_page_link_base_cache}->{$page_name}) {
    return $self->{_page_link_base_cache}->{$page_name};
  }

  my $href = $self->make_page_read_href($page_name);
  $content = WiKicker::HTML::escape($content || $page_name);
  #my $subject = WiKicker::HTML::escape_attribute($self->db->page_subject($page_name));
  #my $link = qq(<a href="$href" title="$subject">$content</a>);
  my $link = qq(<a href="$href">$content</a>);
  if (!$content) {
    $self->{_page_link_base_cache}->{$page_name} = $link;
  }
  return $link;
}

sub make_page_name_link {
  my ($self, $page_name, $fragment_identifier, $content, $mtime_flag, $subject_flag) = @_;
  my ($link, $linked) =
    $self->make_page_name_link_and_linked($page_name, $fragment_identifier,
                                          $content, $mtime_flag, $subject_flag);
  return $link;
}

sub make_page_name_link_and_linked {
  my ($self, $page_name, $fragment_identifier, $content, $mtime_flag, $subject_flag) = @_;
  $page_name = WiKicker::PageName::normalize($page_name);

  # fragment identifier only?
  if ((! $page_name) && $fragment_identifier) {
    my $link = $self->make_fragment_identifier_link($fragment_identifier, $content);
    return ($link, []);
  }

  # exists page?
  #if ($self->db->exists_live_page($page_name)) {
  if ($self->page_name_list->has($page_name)) {
    my $link =  $self->make_exists_page_link($page_name, $content, $mtime_flag, $subject_flag);
    return ($link, [$page_name]);
  }

  # pseudo page?
  if ($self->configuration->is_pseudo_page($page_name)) {
    my $link = $self->make_pseudo_page_link($page_name, $content);
    return ($link, [$page_name]);
  }

  my @full_page_name_list = $self->page_name_list->full_page_name_list($page_name);

  # exists one match page.
  if (@full_page_name_list == 1) {
    my $link =  $self->
      make_exists_page_link($full_page_name_list[0],
                            $content || $page_name,
                            $mtime_flag, $subject_flag);
    return($link, [ $full_page_name_list[0] ]);
  }

  # exists some match pages.
  if (@full_page_name_list > 1) {
    my $content = WiKicker::HTML::escape($content || $page_name);
    my $result = $content;
    my $i = 0;
    for my $full_name (@full_page_name_list) {
      $i++;
      my $href = $self->make_page_read_href($full_name);
      my $title = WiKicker::HTML::escape($full_name);
      $result .= qq([<a href="$href" title="$title">$i</a>]);
    }
    $result .= ' ';
    return ($result, \@full_page_name_list);
  }

  # dangling link
  my $link = $self->make_dangling_link($page_name, $content);
  return ($link, [ $page_name ]);
}


1;
